@@ -22,7 +22,6 @@
 # You should have received a copy of the GNU General Public License
 # along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
 ##
-
 """
 EasyBuild support for building and installing NEURON, implemented as an easyblock
 
@@ -162,19 +161,22 @@ class EB_NEURON(ConfigureMake):
         else:
             self.log.info("Validation of NEURON demo OK!")
 
+        nproc = self.cfg['parallel']
+
         try:
             cwd = os.getcwd()
             os.chdir(os.path.join(self.cfg['start_dir'], 'src', 'parallel'))
 
-            (out, ec) = run_cmd("mpirun -n 10 nrniv -mpi test0.hoc", simple=False, log_all=True, log_output=True)
+            cmd = self.toolchain.mpi_cmd_for("nrniv -mpi test0.hoc", nproc)
+            (out, ec) = run_cmd(cmd, simple=False, log_all=True, log_output=True)
 
             os.chdir(cwd)
         except OSError, err:
             self.log.error("Failed to run parallel hello world: %s" % err)
 
         valid = True
-        for i in range(0, 10):
-            validate_regexp = re.compile("I am %d of 10" % i)
+        for i in range(0, nproc):
+            validate_regexp = re.compile("I am %d of %d" % (i, nproc))
             if not validate_regexp.search(out):
                 valid = False
                 break
